@@ -17,18 +17,16 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include <config.h>
-
 #include "entry-directories.h"
 
 #include <string.h>
 #include <errno.h>
 #include <sys/types.h>
 #include <dirent.h>
+#include <stdlib.h>
 
 #include "menu-util.h"
 #include "menu-monitor.h"
-#include "canonicalize.h"
 
 typedef struct CachedDir CachedDir;
 typedef struct CachedDirMonitor CachedDirMonitor;
@@ -577,7 +575,7 @@ handle_cached_dir_changed (MenuMonitor      *monitor,
          *
          * Additionally, the failure is not upon trying to read the file,
          * but attempting to get its GAppInfo (g_desktop_app_info_new_from_filename()
-         * in desktop-entries.c ln 277).  If you jigger desktop_entry_load() around 
+         * in desktop-entries.c ln 277).  If you jigger desktop_entry_load() around
          * and read the file as a keyfile *first*, it succeeds.  If you then try
          * to run g_desktop_app_info_new_from_keyfile(), *then* it fails.
          *
@@ -838,7 +836,7 @@ entry_directory_new (DesktopEntryType  entry_type,
 
   menu_verbose ("Loading entry directory \"%s\"\n", path);
 
-  canonical = menu_canonicalize_file_name (path, FALSE);
+  canonical = realpath (path, NULL);
   if (canonical == NULL)
     {
       menu_verbose ("Failed to canonicalize \"%s\": %s\n",
@@ -928,7 +926,7 @@ get_desktop_file_id_from_path (EntryDirectory   *ed,
 			       const char       *relative_path)
 {
   char *retval;
-  
+
   retval = NULL;
 
   if (entry_type == DESKTOP_ENTRY_DESKTOP)
